======================================
Available commands and how to use them
======================================

Commands are separated into two grops:

 * Project: commands for setting up and managing Plone/Python projects
 * Server: commands for setting up and managing servers

Project commands
================

.. automodule:: niteoweb.fabfile.project
    :members:


Server commands
===============

.. automodule:: niteoweb.fabfile.server
    :members:
